@@ -26,9 +26,9 @@ except ImportError:
 finally:
     pass
 
-from method_of_moments import soerp_numeric
-from method_of_moments import variance_components
-from method_of_moments import variance_contrib
+from .method_of_moments import soerp_numeric
+from .method_of_moments import variance_components
+from .method_of_moments import variance_contrib
 import scipy.stats as ss
 
 try:
@@ -38,7 +38,7 @@ except ImportError:
 else:
     matplotlib_installed = True
 
-__version_info__ = (0, 9, 5)
+__version_info__ = (0, 9, 6)
 __version__ = '.'.join(list(map(str, __version_info__)))
 
 __author__ = 'Abraham Lee'
@@ -98,6 +98,9 @@ class UncertainFunction(ADF):
 #        # place-holder for pickling
 #        self._hash = None
 
+    def __hash__(self):
+        return id(self)
+        
     _dist = None
     _moments = None
     
@@ -729,7 +732,7 @@ class UncertainVariable(UncertainFunction, ADV):
                 
                 expect = lambda k: rv.dist.expect(lambda x: x**k, args=shape, 
                                                   loc=loc, scale=scale)
-                raw_moments = [expect(k) for k in xrange(1, 9)]
+                raw_moments = [expect(k) for k in range(1, 9)]
                 moments = raw2central(list(raw_moments))
                 for k in range(2, 8):
                     moments[k] = moments[k]/sd**(k + 1)
@@ -739,7 +742,7 @@ class UncertainVariable(UncertainFunction, ADV):
                     "requires a third 'shape' parameter"
                 
                 expect = lambda k: rv.dist.expect(lambda x: x**k)
-                raw_moments = [expect(k) for k in xrange(1, 9)]            
+                raw_moments = [expect(k) for k in range(1, 9)]            
                 moments = raw2central(list(raw_moments))
             
             # update the 1st and second moment values for SOERP calculations
@@ -754,14 +757,9 @@ class UncertainVariable(UncertainFunction, ADV):
         ADV.__init__(self, moments[0], tag=tag)
         self._moments = moments
 
-#    def __hash__(self):
-#        if hasattr(self,'_trace'):
-#            print 'attribute _trace exists:',self._trace
-#            return self._trace
-#        else:
-#            print 'attribute _trace does not exist'
-#            return id(self)
-        
+    def __hash__(self):
+        return id(self)
+                
     @property
     def mean(self):
         return self.moments(0)
@@ -1045,11 +1043,11 @@ def raw2central(v):
     
     v = [1] + v
     central_moments = []
-    for k in xrange(len(v)):
+    for k in range(len(v)):
         val = 0.0
         
         # use the recursion definition to transform
-        for j in xrange(k + 1):
+        for j in range(k + 1):
             val += (-1)**j*nci(k,j)*v[k - j]*v[1]**j
         central_moments.append(val)
     
@@ -1101,7 +1099,7 @@ def covariance_matrix(nums_with_uncert):
     # We symmetrize the matrix:
     for (i, covariance_coefs) in enumerate(cov_matrix):
         covariance_coefs.extend(cov_matrix[j][i]
-                                for j in xrange(i + 1, len(cov_matrix)))
+                                for j in range(i + 1, len(cov_matrix)))
 
     return cov_matrix
 
